%
%   TCoeff_012213_post.M    Post Analysis of the Temperature Coeff 
%                             Experiment performed Jan. 22, 2013
%
%   A pool cooldown experiment was performed in the UMLRR on Jan. 22, 2013.  The 
%   goal here was to measure the combined fuel and coolant temperature coefficient 
%   within the UMLRR.  On Friday Jan. 18, 2013 the reactor was run at near full power 
%   for several hours as a means for heating up the reactor pool (about 76,000 gal of
%   water).  When the run was complete, the pool temperature was in the 95-96 F range.
%   Over the 3-day weekend, the pool cooled by natural convection at the pool surface
%   down to about 85-86 F and the xenon in the system decayed to zero.
%
%   On Tuesday morning (1/22/13), the reactor was brought to a power level of about
%   500 W (this low power is needed so that xenon buildup will not be a factor). With
%   the RegBlade in auto mode,the secondary pump and cooling fans were turned on to 
%   reduce the temperature of the pool water.  With a decreasing temperature, 
%   positive reactivity is inserted because the temperature coeff is negative. 
%   However, since the system was in auto mode, the RegBlade was automatically 
%   inserted into the reactor to compensate for the temperature reactivtiy. 
%
%   With information on the core temperature and RegBlade position vs. time, we 
%   should be able to get a good handle on the temperature reactivtiy and actual
%   temperature coeff. within the UMLRR  --  this is the goal anyway...
%
%   This file does the post analysis calculations for this experiment.  The reactor
%   data for the run have been processed and stored in file pool_cooldown_011413.dat.  
%   This dataset contains information for several different reactor measurements.  
%   The measurements were taken at 1 second intervals, but this info has been 
%   averaged over 30 sec periods.  
%
%   The sequence of steps in the analysis is:
%     1. Read data file and plot some of the data to summarize reactor operations
%        during the run.  The most important parameter, of course, is the reg rod
%        position versus time and the core temperatures vs time.  This step just 
%        validates that we have the correct data (visualization was already done 
%        with the umlrr_data GUI).
%     2. Use the RR blade worth curve and measured z(t) to generate rho(t) due to
%        the temperature change in the system (xenon is neglected here because of 
%        the low power level).
%     3. Plot rho(t) vs Tcore(t) where Tcore is the average of Tin and Tout.  The 
%        slope of this curve is the desired temperature coefficient.
%
%   File prepared by J. R. White, UMass-Lowell (Jan. 22, 2013)
%   Update #1:
%   Code modified to use recent function files and to clean up some edit -- however,
%   no fundamental changes were made and there was no change in the results.  
%   Basically, just did some house cleaning...              (JRWhite, March 2, 2014)
%   Update #2:
%   Added a temperature vs. time plot with only Tin and Tout for the core (less 
%   confusing when trying to explain this expt)             (JRWhite, Nov. 21, 2015)

      clear all, close all, nfig = 0;
%
%   read experimental data
      fname = 'pool_cooldown_012213.dat';
      [data,tags,exptdate,starttime] = read_datfile(fname); 
%
%   plot some data to view reactor operation during the run
      teh = data(:,1)/3600;      % time vector for expt (hous)
      tunits = 'hours';          % time units for plots
      titl = 'TCoeff\_012213';   % for use in title of plots
      nfig = plot_PTB(teh,data,tags,exptdate,nfig,titl,tunits);  
%%
%   get compensated reactivity and Tcore vs time 
      itag = gettagloc('RRodPos ',tags);  z = data(:,itag);   % reg blade loc vs time 
      itag = gettagloc('CoreTin ',tags);  Tin = data(:,itag); % Tin (oF) 
      itag = gettagloc('CoreTout',tags);  Tout = data(:,itag);% Tout (oF) 
      RBdate = 'Feb. 2013';  boi = 5;  yr = 2013;
      rhoT = bworth(z,boi,yr)-bworth(z(1),boi,yr);% compensated rho %Dk/k
      rhoTT = -rhoT;                              % change sign (make positive)
%      rhoTT = rhoT;                              % change sign (make positive)
      Tcore = (Tin+Tout)/2;                       % core ave temp (oF)
      rp = 0.00054;                               % rel power (frac of 1 MW) (540 W)
%%
%   process/plot results
      iu = menu('Select Temperatuyre Units', ...
                '   Use default oF units    ', ...
                '   Convert everything to oC units');
      Tunits = 'F';
      if iu == 2,  Tunits = 'C';  Tcore = (5/9)*(Tcore-32);  end
%
      nfig   = nfig+1;   figure(nfig);
      plot(teh,Tcore,'r-','LineWidth',2),grid
      title(['TCoeff\_012213: Measured T_{core} vs. Time for Experiment on ',exptdate])
      xlabel('Elapsed Time (hours)'),ylabel(['Temperature (^o',Tunits,')'])
%
      nfig   = nfig+1;   figure(nfig);
      plot(Tcore,rhoTT,'r-','LineWidth',2),grid
      title(['TCoeff\_012213: Measured \rho_{Temp} vs. T_{core} for Experiment on ',exptdate])
      xlabel(['Temperature (^o',Tunits,')']),ylabel('Reactivtiy (% \Deltak/k)')
%
%   determine slope of reactivity vs temperature curve
      cfit1 = polyfit(Tcore,rhoTT,1);             % coeffs of linear fit
      rhoTTfit1 = polyval(cfit1,Tcore);           % linear fit
      alphaT1 = cfit1(1);                         % temp coeff  
      cfit2 = polyfit(Tcore,rhoTT,2);             % coeffs of quadratic fit
      rhoTTfit2 = polyval(cfit2,Tcore);           % quadratic fit
      alphaT2 = 2*cfit2(1)*Tcore + cfit2(2);      % temp coeff vs T 
      cfit3 = polyfit(Tcore,rhoTT,3);             % coeffs of cubic fit
      rhoTTfit3 = polyval(cfit3,Tcore);           % cubic fit
      alphaT3 = 3*cfit3(1)*Tcore.^2 + 2*cfit3(2)*Tcore + cfit3(3); % temp coeff vs T 
%
%   plot the reactivity versus temperature and linear fit
      nfig = nfig+1;  figure(nfig);
      plot(Tcore,rhoTTfit1,'r-',Tcore,rhoTT,'b.','LineWidth',2),grid
      title(['TCoeff\_012213:  Reactivity Versus Core Temperature' ...
             ' (RP = ',num2str(rp,'%7.5f'),')'])
      xlabel(['Temperature (^o',Tunits,')']),ylabel('Reactivity Change (% \Deltak/k)')
      legend('Linear Fit','Expt. Data')
      gtext(['\alpha_T = ',num2str(alphaT1,'%8.3e'),' % \Deltak/k per ^o',Tunits])
%
%   plot the reactivity versus temperature and quadratic fit
      nfig = nfig+1;  figure(nfig);
      plot(Tcore,rhoTTfit2,'r-',Tcore,rhoTT,'b.','LineWidth',2),grid
      title(['TCoeff\_012213:  Reactivity Versus Core Temperature' ...
             ' (RP = ',num2str(rp,'%7.5f'),')'])
      xlabel(['Temperature (^o',Tunits,')']),ylabel('Reactivity Change (% \Deltak/k)')
      legend('Quadratic Fit','Expt. Data')
      gtext(['\alpha_T(T) = (',num2str(2*cfit2(1),'%8.3e'),') * T + (', ...
                             num2str(cfit2(2),'%8.3e'),') % \Deltak/k per ^o',Tunits])
%
%   for the quadratic polynomical case, plot temp coeff vs temp (a linear function)
      nfig = nfig+1;  figure(nfig);
      plot(Tcore,alphaT2,'r-','LineWidth',2),grid
      title(['TCoeff\_012213:  Temp. Coeff. Vs Core Temp.' ...
             ' (RP = ',num2str(rp,'%7.5f'),')'])
      xlabel(['Temperature (^o',Tunits,')'])
      ylabel(['Temperature Coefficient (% \Deltak/k per ^o',Tunits,')'])
%
%   plot the reactivity versus temperature and cubic fit
      nfig = nfig+1;  figure(nfig);
      plot(Tcore,rhoTTfit3,'r-',Tcore,rhoTT,'b.','LineWidth',2),grid
      title(['TCoeff\_012213:  Reactivity Versus Core Temperature' ...
             ' (RP = ',num2str(rp,'%6.4f'),')'])
      xlabel(['Temperature (^o',Tunits,')']),ylabel('Reactivity Change (% \Deltak/k)')
      legend('Cubic Fit','Expt. Data')
      gtext(['\alpha_T(T) = (',num2str(3*cfit3(1),'%8.3e'),') * T^2 + (', ...
                             num2str(2*cfit3(2),'%8.3e'),') *T + (', ...
                             num2str(cfit3(3),'%8.3e'),') % \Deltak/k per ^o',Tunits])
%
%   for the cubic polynomical case, plot temp coeff vs temp (a quadratic function)
      nfig = nfig+1;  figure(nfig);
      plot(Tcore,alphaT3,'r-','LineWidth',2),grid
      title(['TCoeff1\_012213:  Temp. Coeff. Vs Core Temp.' ...
             ' (RP = ',num2str(rp,'%6.4f'),')'])
      xlabel(['Temperature (^o',Tunits,')'])
      ylabel(['Temperature Coefficient (% \Deltak/k per ^o',Tunits,')'])
%
%   end of program